==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/serverinfo/l10n/fr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Information CPU non disponible",
    "Load average: {cpu} (last minute)" : "Moyenne de la charge : {cpu} (dernière minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM : Total : {memTotalBytes}/Utilisation actuelle : {memUsageBytes}",
    "RAM info not available" : "Informations sur la RAM non disponibles",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP : Total : {swapTotalBytes}/Utilisation actuelle : {swapUsageBytes}",
    "SWAP info not available" : "L'information SWAP n'est pas disponible",
    "Copied!" : "Copié !",
    "Not supported!" : "Non supporté !",
    "Press ⌘-C to copy." : "Pressez ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
    "System" : "Système",
    "Monitoring" : "Surveillance",
    "Monitoring app with useful server information" : "Application de surveillance avec les informations utiles du serveur",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fournit des informations utiles sur le serveur, telles que la charge du processeur, l'utilisation de la RAM, l'utilisation du disque, le nombre d'utilisateurs, etc.",
    "Operating System:" : "Système d'exploitation :",
    "CPU:" : "CPU :",
    "Unknown Processor" : "Processeur inconnu",
    "Memory:" : "Mémoire :",
    "Server time:" : "Heure du serveur :",
    "Uptime:" : "Durée de fonctionnement :",
    "Temperature" : "Température",
    "Load" : "Charge",
    "Memory" : "Mémoire",
    "Disk" : "Disque",
    "Mount:" : "Montage :",
    "Filesystem:" : "Système de fichiers :",
    "Size:" : "Taille :",
    "Available:" : "Disponible :",
    "Used:" : "Utilisé :",
    "Files:" : "Fichiers :",
    "Storages:" : "Stockages :",
    "Free Space:" : "Espace libre :",
    "Network" : "Réseau",
    "Hostname:" : "Nom d'hôte :",
    "DNS:" : "DNS :",
    "Gateway:" : "Passerelle :",
    "Status:" : "État :",
    "Speed:" : "Vitesse :",
    "Duplex:" : "Duplex :",
    "MAC:" : "MAC :",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Utilisateurs actifs",
    "Total users:" : "Nombre total d'utilisateurs :",
    "24 hours:" : "24 heures :",
    "1 hour:" : "1 heure :",
    "5 mins:" : "5 minutes :",
    "Shares" : "Partages",
    "Users:" : "Utilisateurs :",
    "Groups:" : "Groupes :",
    "Links:" : "Liens :",
    "Emails:" : "E-mails :",
    "Federated sent:" : "Offre de fédération envoyée :",
    "Federated received:" : "Offre de fédération reçue :",
    "Talk conversations:" : "Conversations Talk :",
    "PHP" : "PHP",
    "Version:" : "Version :",
    "Memory limit:" : "Limite de mémoire :",
    "Max execution time:" : "Temps d'exécution maximal :",
    "Upload max size:" : "Taille de téléversement maximale :",
    "OPcache Revalidate Frequency:" : "Fréquence de revalidation de l'OPcache :",
    "Extensions:" : "Extensions :",
    "Unable to list extensions" : "Impossible de lister les extensions",
    "Show phpinfo" : "Afficher phpinfo",
    "Database" : "Base de données",
    "Type:" : "Type :",
    "External monitoring tool" : "Outil de surveillance externe",
    "Use this end point to connect an external monitoring tool:" : "Utiliser ce point de terminaison pour connecter un outil de surveillance externe :",
    "Copy" : "Copier",
    "Output in JSON" : "Sortie en JSON",
    "Skip app updates (including app updates will send an external request to the app store)" : "Ignorer les mises à jour des applications (les mises à jour des applications incluses vont envoyer une requête externe au magasin d'applications).",
    "Skip server update" : "Ignorer la mise à jour du serveur",
    "To use an access token, please generate one then set it using the following command:" : "Pour utiliser un jeton d'accès, veuillez en générer un puis le définir à l'aide de la commande suivante :",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Puis transmettez le jeton avec l'entête « NC-Token » lorsque vous appelez l'URL."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php83-nextcloud-30.0.11.tgz: share/nextcloud/apps/serverinfo/l10n/fr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Information CPU non disponible",
    "CPU Usage:" : "Usage CPU:",
    "Load average: {percentage} % ({load}) last minute" : "Moyenne de la charge : {percentage}% ( {load}) dernière minute",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) dernière Minute\n{last5MinutesPercentage} % ({last5Minutes}) 5 dernières Minutes\n{last15MinutesPercentage} % ({last15Minutes}) 15 dernières Minutes",
    "RAM Usage:" : "Usage RAM:",
    "SWAP Usage:" : "Usage SWAP:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM : Total : {memTotalBytes}/Utilisation actuelle : {memUsageBytes}",
    "RAM info not available" : "Informations sur la RAM non disponibles",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP : Total : {swapTotalBytes}/Utilisation actuelle : {swapUsageBytes}",
    "SWAP info not available" : "L'information SWAP n'est pas disponible",
    "Copied!" : "Copié !",
    "Not supported!" : "Non supporté !",
    "Press ⌘-C to copy." : "Pressez ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
    "System" : "Système",
    "Monitoring" : "Surveillance",
    "Monitoring app with useful server information" : "Application de surveillance avec les informations utiles du serveur",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fournit des informations utiles sur le serveur, telles que la charge du processeur, l'utilisation de la RAM, l'utilisation du disque, le nombre d'utilisateurs, etc.",
    "Operating System:" : "Système d’exploitation :",
    "CPU:" : "CPU :",
    "Unknown Processor" : "Processeur inconnu",
    "Memory:" : "Mémoire :",
    "Server time:" : "Heure du serveur :",
    "Uptime:" : "Durée de fonctionnement :",
    "Temperature" : "Température",
    "Load" : "Charge",
    "Memory" : "Mémoire",
    "Disk" : "Disque",
    "Mount:" : "Montage :",
    "Filesystem:" : "Système de fichiers :",
    "Size:" : "Taille :",
    "Available:" : "Disponible :",
    "Used:" : "Utilisé :",
    "Files:" : "Fichiers :",
    "Storages:" : "Stockages :",
    "Free Space:" : "Espace libre :",
    "Network" : "Réseau",
    "Hostname:" : "Nom d'hôte :",
    "Gateway:" : "Passerelle :",
    "Status:" : "État :",
    "Speed:" : "Vitesse :",
    "Duplex:" : "Duplex :",
    "MAC:" : "MAC :",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Utilisateurs actifs",
    "Last hour" : "Dernière heure",
    "%s%% of all users" : "%s%% pour tous les utilisateurs",
    "Last 24 Hours" : "Dernières 24 heures",
    "Last 7 Days" : "7 derniers jours",
    "Last 30 Days" : "30 derniers jours",
    "Shares" : "Partages",
    "Users:" : "Utilisateurs :",
    "Groups:" : "Groupes :",
    "Links:" : "Liens :",
    "Emails:" : "E-mails :",
    "Federated sent:" : "Offre de fédération envoyée :",
    "Federated received:" : "Offre de fédération reçue :",
    "Talk conversations:" : "Conversations Talk :",
    "PHP" : "PHP",
    "Version:" : "Version :",
    "Memory limit:" : "Limite de mémoire :",
    "Max execution time:" : "Temps d’exécution maximal :",
    "Upload max size:" : "Taille de téléversement maximale :",
    "OPcache Revalidate Frequency:" : "Fréquence de revalidation de l'OPcache :",
    "Extensions:" : "Extensions :",
    "Unable to list extensions" : "Impossible de lister les extensions",
    "Show phpinfo" : "Afficher phpinfo",
    "Database" : "Base de données",
    "Type:" : "Type :",
    "External monitoring tool" : "Outil de surveillance externe",
    "Use this end point to connect an external monitoring tool:" : "Utiliser ce point de terminaison pour connecter un outil de surveillance externe :",
    "Copy" : "Copier",
    "Output in JSON" : "Sortie en JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Ignorer la section des applications (y compris la section des applications enverra une demande externe à l'App Store)",
    "Skip server update" : "Ignorer la mise à jour du serveur",
    "To use an access token, please generate one then set it using the following command:" : "Pour utiliser un jeton d'accès, veuillez en générer un puis le définir à l'aide de la commande suivante :",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Puis transmettez le jeton avec l’entête « NC-Token » lorsque vous appelez l’URL.",
    "Load average: {cpu} (last minute)" : "Moyenne de la charge : {cpu} (dernière minute)",
    "DNS:" : "DNS :",
    "Total users:" : "Nombre total d’utilisateurs :",
    "24 hours:" : "24 heures :",
    "1 hour:" : "1 heure :",
    "5 mins:" : "5 minutes :"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
